@@ -19,7 +19,7 @@
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 
 -- |
--- Module      :  Language.Haskell.TH.Instances.Lift
+-- Module      :  Language.Haskell.TH.Instances
 -- Copyright   :  (c) Matt Morrow 2008
 -- License     :  BSD3
 -- Maintainer  :  Michael Sloan <mgsloan at gmail>
@@ -47,6 +47,10 @@
 -- Note that the 'Ord' instances are not guaranteed to produce
 -- consistent results across template-haskell / GHC versions, as they
 -- have different data types, with different constructor orders.
+--
+-- This module also implicitly re-exports the instances defined in
+-- "Instances.TH.Lift". This is mostly to ensure that there aren't
+-- collisions of orphans between @th-orphans@ and @th-lift-instances@.
 module Language.Haskell.TH.Instances () where
 
 import Language.Haskell.TH
@@ -60,6 +64,7 @@ import Control.Monad.RWS (RWST(RWST), runRWST)
 import Control.Monad.State (StateT(StateT), runStateT)
 import Control.Monad.Writer (WriterT(WriterT), runWriterT)
 import qualified Control.Monad.Trans as MTL (lift)
+import Instances.TH.Lift ()
 
 -- Thanks to Richard Eisenberg, GHC 7.10 adds many of the instances
 -- from this module.
@@ -98,6 +103,11 @@ import qualified Generics.Deriving.TH as Generic (deriveAll)
 # endif
 #endif
 
+#if !MIN_VERSION_template_haskell(2,11,0)
+deriving instance Show NameFlavour
+deriving instance Show NameSpace
+#endif
+
 -- Ideally, it'd be possible to use reifyManyWithoutInstances for
 -- these Ord instances, but TH can't output deriving instances (and
 -- even if this is added for later versions, we need to support many
@@ -110,40 +120,6 @@ import qualified Generics.Deriving.TH as Generic (deriveAll)
 instance Ppr Lit where
     ppr = pprLit noPrec
 
--- This follows the pattern of the Lift instances for Int / Integer.
-instance Lift Int8 where
-    lift x = return (LitE (IntegerL (fromIntegral x)))
-
-instance Lift Int16 where
-    lift x = return (LitE (IntegerL (fromIntegral x)))
-
-instance Lift Int32 where
-    lift x = return (LitE (IntegerL (fromIntegral x)))
-
-instance Lift Int64 where
-    lift x = return (LitE (IntegerL (fromIntegral x)))
-
-instance Lift Word where
-    lift x = return (LitE (IntegerL (fromIntegral x)))
-
-instance Lift Word8 where
-    lift x = return (LitE (IntegerL (fromIntegral x)))
-
-instance Lift Word16 where
-    lift x = return (LitE (IntegerL (fromIntegral x)))
-
-instance Lift Word32 where
-    lift x = return (LitE (IntegerL (fromIntegral x)))
-
-instance Lift Word64 where
-    lift x = return (LitE (IntegerL (fromIntegral x)))
-
-instance Lift Float where
-    lift x = return (LitE (RationalL (toRational x)))
-
-instance Lift Double where
-    lift x = return (LitE (RationalL (toRational x)))
-
 deriving instance Eq Info
 
 deriving instance Ord Body
@@ -389,6 +365,12 @@ instance Quasi m => Quasi (ReaderT r m) where
   qGetQ               = MTL.lift qGetQ
   qPutQ               = MTL.lift . qPutQ
 # endif
+# if MIN_VERSION_template_haskell(2,11,0)
+  qReifyFixity        = MTL.lift . qReifyFixity
+  qReifyConStrictness = MTL.lift . qReifyConStrictness
+  qIsExtEnabled       = MTL.lift . qIsExtEnabled
+  qExtsEnabled        = MTL.lift qExtsEnabled
+# endif
 #elif MIN_VERSION_template_haskell(2,5,0)
   qClassInstances a b = MTL.lift $ qClassInstances a b
 #endif
@@ -413,6 +395,12 @@ instance (Quasi m, Monoid w) => Quasi (WriterT w m) where
   qGetQ               = MTL.lift qGetQ
   qPutQ               = MTL.lift . qPutQ
 # endif
+# if MIN_VERSION_template_haskell(2,11,0)
+  qReifyFixity        = MTL.lift . qReifyFixity
+  qReifyConStrictness = MTL.lift . qReifyConStrictness
+  qIsExtEnabled       = MTL.lift . qIsExtEnabled
+  qExtsEnabled        = MTL.lift qExtsEnabled
+# endif
 #elif MIN_VERSION_template_haskell(2,5,0)
   qClassInstances a b = MTL.lift $ qClassInstances a b
 #endif
@@ -437,6 +425,12 @@ instance Quasi m => Quasi (StateT s m) where
   qGetQ               = MTL.lift qGetQ
   qPutQ               = MTL.lift . qPutQ
 # endif
+# if MIN_VERSION_template_haskell(2,11,0)
+  qReifyFixity        = MTL.lift . qReifyFixity
+  qReifyConStrictness = MTL.lift . qReifyConStrictness
+  qIsExtEnabled       = MTL.lift . qIsExtEnabled
+  qExtsEnabled        = MTL.lift qExtsEnabled
+# endif
 #elif MIN_VERSION_template_haskell(2,5,0)
   qClassInstances a b = MTL.lift $ qClassInstances a b
 #endif
@@ -461,6 +455,12 @@ instance (Quasi m, Monoid w) => Quasi (RWST r w s m) where
   qGetQ               = MTL.lift qGetQ
   qPutQ               = MTL.lift . qPutQ
 # endif
+# if MIN_VERSION_template_haskell(2,11,0)
+  qReifyFixity        = MTL.lift . qReifyFixity
+  qReifyConStrictness = MTL.lift . qReifyConStrictness
+  qIsExtEnabled       = MTL.lift . qIsExtEnabled
+  qExtsEnabled        = MTL.lift qExtsEnabled
+# endif
 #elif MIN_VERSION_template_haskell(2,5,0)
   qClassInstances a b = MTL.lift $ qClassInstances a b
 #endif
